@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,7 +15,7 @@
 #
 # END HEADER
 
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
 from hypothesis.errors import FailedHealthCheck
 
@@ -28,9 +28,9 @@ def fail_health_check(settings, message, label):
     if label in settings.suppress_health_check:
         return
     message += (
-        '\nSee https://hypothesis.readthedocs.io/en/latest/health'
-        'checks.html for more information about this. '
-        'If you want to disable just this health check, add %s '
-        'to the suppress_health_check settings for this test.'
+        "\nSee https://hypothesis.readthedocs.io/en/latest/health"
+        "checks.html for more information about this. "
+        "If you want to disable just this health check, add %s "
+        "to the suppress_health_check settings for this test."
     ) % (label,)
     raise FailedHealthCheck(message, label)
